==> v1.0.2.zip: portfolio/web/src/Routes.tsx <==
import { Router, Route, Set, PrivateSet } from '@redwoodjs/router'

import { useAuth } from 'src/auth'
import AccountbarLayout from 'src/layouts/AccountbarLayout'
import NavbarLayout from 'src/layouts/NavbarLayout/NavbarLayout'
import ScaffoldLayout from 'src/layouts/ScaffoldLayout/ScaffoldLayout'

const Routes = () => {
  return (
    <Router useAuth={useAuth}>
      <PrivateSet unauthenticated="home">
        <Set wrap={ScaffoldLayout} title="Tags" titleTo="tags" buttonLabel="New Tag" buttonTo="newTag">
          <Route path="/admin/tags/new" page={TagNewTagPage} name="newTag" />
          <Route path="/admin/tags/{id:Int}/edit" page={TagEditTagPage} name="editTag" />
          <Route path="/admin/tags/{id:Int}" page={TagTagPage} name="tag" />
          <Route path="/admin/tags" page={TagTagsPage} name="tags" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Socials" titleTo="socials" buttonLabel="New Social" buttonTo="newSocial">
          <Route path="/admin/socials/new" page={SocialNewSocialPage} name="newSocial" />
          <Route path="/admin/socials/{id:Int}/edit" page={SocialEditSocialPage} name="editSocial" />
          <Route path="/admin/socials/{id:Int}" page={SocialSocialPage} name="social" />
          <Route path="/admin/socials" page={SocialSocialsPage} name="socials" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Portrait" titleTo="portrait">
          <Route path="/admin/portrait" page={PortraitPortraitPage} name="portrait" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Titles" titleTo="titles">
          <Route path="/admin/titles" page={TitleTitlesPage} name="titles" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Resume" titleTo="adminResume">
          <Route path="/admin/resume" page={ResumeAdminResumePage} name="adminResume" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Projects" titleTo="projects" buttonLabel="New Project" buttonTo="newProject">
          <Route path="/admin/projects/new" page={ProjectNewProjectPage} name="newProject" />
          <Route path="/admin/projects/{id:Int}/edit" page={ProjectEditProjectPage} name="editProject" />
          <Route path="/admin/projects/{id:Int}" page={ProjectAdminProjectPage} name="adminProject" />
          <Route path="/admin/projects" page={ProjectAdminProjectsPage} name="adminProjects" />
        </Set>
      </PrivateSet>

      <Set wrap={AccountbarLayout} title="Login">
        <Route path="/login" page={LoginPage} name="login" />
      </Set>

      <Set wrap={AccountbarLayout} title="Forgot Password">
        <Route path="/forgot-password" page={ForgotPasswordPage} name="forgotPassword" />
      </Set>

      <Set wrap={AccountbarLayout} title="Reset Password">
        <Route path="/reset-password" page={ResetPasswordPage} name="resetPassword" />
      </Set>

      <Set wrap={NavbarLayout}>
        <Route path="/" page={HomePage} name="home" />
        <Route path="/projects" page={ProjectProjectsPage} name="projects" />
        <Route path="/project/{id:Int}" page={ProjectProjectPage} name="project" />
        <Route path="/contact" page={ContactPage} name="contact" />
        <Route path="/resume" page={ResumeResumePage} name="resume" />
      </Set>

      <Route notfound page={NotFoundPage} />
    </Router>
  )
}

export default Routes

==> v1.1.6-1.zip: portfolio/web/src/Routes.tsx <==
import { Router, Route, Set, PrivateSet } from '@redwoodjs/router'

import { useAuth } from 'src/auth'
import AccountbarLayout from 'src/layouts/AccountbarLayout'
import NavbarLayout from 'src/layouts/NavbarLayout/NavbarLayout'
import ScaffoldLayout from 'src/layouts/ScaffoldLayout/ScaffoldLayout'

const Routes = () => {
  return (
    <Router useAuth={useAuth}>
      <PrivateSet unauthenticated="home">
        <Set wrap={ScaffoldLayout} title="Tags" titleTo="tags" buttonLabel="New Tag" buttonTo="newTag">
          <Route path="/admin/tags/new" page={TagNewTagPage} name="newTag" />
          <Route path="/admin/tags/{id:Int}/edit" page={TagEditTagPage} name="editTag" />
          <Route path="/admin/tags/{id:Int}" page={TagTagPage} name="tag" />
          <Route path="/admin/tags" page={TagTagsPage} name="tags" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Socials" titleTo="socials" buttonLabel="New Social" buttonTo="newSocial">
          <Route path="/admin/socials/new" page={SocialNewSocialPage} name="newSocial" />
          <Route path="/admin/socials/{id:Int}/edit" page={SocialEditSocialPage} name="editSocial" />
          <Route path="/admin/socials/{id:Int}" page={SocialSocialPage} name="social" />
          <Route path="/admin/socials" page={SocialSocialsPage} name="socials" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Portrait" titleTo="portrait">
          <Route path="/admin/portrait" page={PortraitPortraitPage} name="portrait" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Titles" titleTo="titles">
          <Route path="/admin/titles" page={TitleTitlesPage} name="titles" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Résumé" titleTo="adminResume">
          <Route path="/admin/resume" page={ResumeAdminResumePage} name="adminResume" />
        </Set>

        <Set wrap={ScaffoldLayout} title="Projects" titleTo="adminProjects" buttonLabel="New Project" buttonTo="newProject">
          <Route path="/admin/projects/new" page={ProjectNewProjectPage} name="newProject" />
          <Route path="/admin/projects/{id:Int}/edit" page={ProjectEditProjectPage} name="editProject" />
          <Route path="/admin/projects/{id:Int}" page={ProjectAdminProjectPage} name="adminProject" />
          <Route path="/admin/projects" page={ProjectAdminProjectsPage} name="adminProjects" />
        </Set>
      </PrivateSet>

      <Set wrap={AccountbarLayout} title="Login">
        <Route path="/login" page={LoginPage} name="login" />
      </Set>

      <Set wrap={AccountbarLayout} title="Forgot Password">
        <Route path="/forgot-password" page={ForgotPasswordPage} name="forgotPassword" />
      </Set>

      <Set wrap={AccountbarLayout} title="Reset Password">
        <Route path="/reset-password" page={ResetPasswordPage} name="resetPassword" />
      </Set>

      <Set wrap={NavbarLayout}>
        <Route path="/" page={HomePage} name="home" />
        <Route path="/projects" page={ProjectProjectsPage} name="projects" />
        <Route path="/project/{id:Int}" page={ProjectProjectPage} name="project" />
        <Route path="/contact" page={ContactPage} name="contact" />
        <Route path="/resume" page={ResumeResumePage} name="resume" />
      </Set>

      <Route notfound page={NotFoundPage} />
    </Router>
  )
}

export default Routes
